#!/bin/bash

##### Check if the installation has been halted.
if [ -e ../.halted ]; then
	rm -f ../.halted
	exit
fi

echo === ZyConfig Install Script ============================

# This file is run as a part of the generalized installer
# for the Zytronic Touchscreen Linux Drivers

# It should move the pre-compiled binaries to their appropriate 
# locations, leaving ZyConfig ready for use.

# It will halt if there is no driver installed on the system

# When run successfully on the target machine, ZyConfig should 
# be available on the commandline. Some distributions may
# require it to be run with root permissions.

# The script expects binaries to be available in the current 
# directory, with the architecture prefixed:
#	amd64_ZyConfig
#	i386_ZyConfig
#	armv7l_ZyConfig


##### verify that the modules loaded

MOD_LIST=`lsmod | grep ^zxy | wc -l`
if [ $MOD_LIST -lt 2 ]; then
	echo === Failed to find modules in kernel ===================
	exit 1
fi


##### Verify root privileges

USER_ID=`id -u`
if [ ${USER_ID} != 0 ]; then
	echo === User must be root. =================================
	echo -e "try\n $ su -\nor\n $ sudo $@"
	exit 1
fi


##### Ensure user wants this 

read -n1 -p "Do you wish to install ZyConfig (Qt required) [y/n]? " agreeYN
if [[ ! "$agreeYN" =~ [yY] ]]; then
	echo -e "\n  Ok. Installation halted."
	exit 0
else
	echo 
fi


##### select the architecture

tryMachineName=0
ARCH=`uname -p` # get processor instruction set type
if [ $ARCH == unknown ]; then
	ARCH=`uname -m`
fi
case "$ARCH" in
i[3456]86)
	echo ix86 executables to be installed
	ARCH=ix86
	;;
amd64)
	echo amd64/x86_64 executables to be installed
	ARCH=amd64
	;;
x86_64)
	echo amd64/x86_64 executables to be installed
	ARCH=amd64
	;;
armv7l)
	echo ARM v7l executables to be installed 
	echo -e "   Generally, the Soft-Float should be installed, but Hard-Float is available:\n"
	read -n1 -p "   Do you wish to install the Hard-Float option [n]? " agreeYN
	if [[ ! "$agreeYN" =~ [yY] ]]; then
		ARCH=armv7l_sf
	else
		ARCH=armv7l_hf
	fi
	;;
*)
	echo "Unrecognised processor name (uname -p => $ARCH)"
	tryMachineName=1
	;;
esac

if [ $tryMachineName -eq 1 ]; then

	ARCH=`uname -m`

	case "$ARCH" in
	i[3456]86)
		echo ix86 executables to be installed
		ARCH=ix86
		;;
	amd64)
		echo amd64/x86_64 executables to be installed
		ARCH=amd64
		;;
	x86_64)
		echo amd64/x86_64 executables to be installed
		ARCH=amd64
		;;
	armv7l)
		echo ARM v7l executables to be installed 
		echo -e "   Generally, the Soft-Float should be installed, but Hard-Float is available:\n"
		read -n1 -p "   Do you wish to install the Hard-Float option [n]? " agreeYN
		if [[ ! "$agreeYN" =~ [yY] ]]; then
			ARCH=armv7l_sf
		else
			ARCH=armv7l_hf
		fi
		;;
	*)
		echo "Unrecognised machine name (uname -m => $ARCH)"
		tryMachineName=1
		;;
	esac


fi

##### verify that the correct binary is available
if [ ! -e ./${ARCH}_ZyConfig ]; then
	echo The required ZyConfig is not available in this package
	exit 2
fi

##### check ZyConfig dependencies

ldd ${ARCH}_ZyConfig 2>./errLib.txt 1>/dev/null
libraryErrors=( $(wc -l ./errLib.txt) )
if [ 0 -ne $libraryErrors ]; then
	echo "Library Issues:"
	cat ./errLib.txt
	touch ./.halted
fi 
rm ./errLib.txt

depString=`ldd ${ARCH}_ZyConfig | cut -f 1 -d " " | grep -v linux`
zyconfigLibs=( $depString )
echo -e "Checking for required libraries:"
echo "    ${zyconfigLibs[*]}"
for library in "${zyconfigLibs[@]}"
do
	ldconfig -p | grep $library > /dev/null
	if [ $? -ne 0 ]; then
		echo "    Dependency $library MISSING!"
		touch ./.halted
	fi
done

##### if a dependent library is missing, halt

if [ -e ./.halted ]; then
	rm -f ./.halted
	echo -e "\n### Some libraries are missing    ###\n### ZyConfig installation aborted ###\n"
	echo "Please install or update the libraries identified"
	echo "and reinstall ZyConfig, with the command :"
	echo "$ ./install.sh zyconfig"
	exit 1
fi

echo "    All libraries found, installing ZyConfig ..."

##### Check for a gksudo (or similar service)
./check-sudo-gui.sh

##### add the executables

install -o root -g root -p -m 755 ${ARCH}_ZyConfig /usr/bin/ZyConfig
install -o root -g root -p -m 755 ${ARCH}_TouchTest /usr/bin/TouchTest

# NB - we SHOULD check the dependencies of TouchTest" also !!

##### warn if the lock directory is not accessible
if [ ! -w /var/lock ]; then 
	echo -e "\n\nZyConfig needs access to the directory /var/lock"
	if [ ! -e /var/lock ]; then 
		echo Create the directory: $ sudo mkdir /var/lock/ 
	fi
	echo -e "Write access should be granted when needed: $ sudo chmod o+w /var/lock/\n"
fi


echo === ZyConfig Install ========================= DONE ====
